==> openGion6.0.0.1_core.zip: uap/webapps/ge/db/postgres/sql/install/01_TABLE/GE30S.sql <==
/****************************************************************************/
/* GE30 ( ﾊﾟﾗﾒｰﾀﾃｰﾌﾞﾙ )                                                     */
/*                                                                          */
/* Created : 2014/04/26 11:19:58                                            */
/****************************************************************************/
CREATE TABLE GE30 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID           */
 , PTN_ID       VARCHAR (   20 )                    NOT NULL            /*  20 定型文ID         */
 , FROM_ID      VARCHAR (   50 )                    NOT NULL            /*  30 送信者ID         */
 , TO_ID        VARCHAR ( 4000 )                                        /*  40 宛先(TO)         */
 , CC_ID        VARCHAR ( 4000 )                                        /*  50 宛先(CC)         */
 , BCC_ID       VARCHAR ( 4000 )                                        /*  60 宛先(BCC)        */
 , H_TXT        VARCHAR ( 1000 )                                        /*  70 ﾍｯﾀﾞｰ自由文      */
 , F_TXT        VARCHAR ( 1000 )                                        /*  80 ﾌｯﾀｰ自由文       */
 , GAMEN_URL    VARCHAR (  300 )                                        /*  90 画面URL(暗号化)  */
 , PARAM0       VARCHAR ( 4000 )                                        /* 100 ﾊﾟﾗﾒｰﾀ0          */
 , PARAM1       VARCHAR ( 4000 )                                        /* 110 ﾊﾟﾗﾒｰﾀ1          */
 , PARAM2       VARCHAR ( 1000 )                                        /* 120 ﾊﾟﾗﾒｰﾀ2          */
 , PARAM3       VARCHAR ( 1000 )                                        /* 130 ﾊﾟﾗﾒｰﾀ3          */
 , PARAM4       VARCHAR ( 1000 )                                        /* 140 ﾊﾟﾗﾒｰﾀ4          */
 , PARAM5       VARCHAR ( 1000 )                                        /* 150 ﾊﾟﾗﾒｰﾀ5          */
 , PARAM6       VARCHAR ( 1000 )                                        /* 160 ﾊﾟﾗﾒｰﾀ6          */
 , PARAM7       VARCHAR ( 1000 )                                        /* 170 ﾊﾟﾗﾒｰﾀ7          */
 , PARAM8       VARCHAR ( 1000 )                                        /* 180 ﾊﾟﾗﾒｰﾀ8          */
 , PARAM9       VARCHAR ( 1000 )                                        /* 190 ﾊﾟﾗﾒｰﾀ9          */
 , ATTACH1      VARCHAR (  256 )                                        /* 200 添付1            */
 , ATTACH2      VARCHAR (  256 )                                        /* 210 添付2            */
 , ATTACH3      VARCHAR (  256 )                                        /* 220 添付3            */
 , ATTACH4      VARCHAR (  256 )                                        /* 230 添付4            */
 , ATTACH5      VARCHAR (  256 )                                        /* 240 添付5            */
 , SNDTIME      VARCHAR (   14 )                    NOT NULL            /* 240 送信日時         */
 , UNIQ         SERIAL                                                  /* 800 ﾕﾆｰｸｷｰ           */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET        VARCHAR (   14 )                                        /* 820 登録日時         */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG           */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG         */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成社員         */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時         */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG           */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG         */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者           */
);

==> openGion6.0.1.2_core.zip: uap/webapps/ge/db/postgres/sql/install/01_TABLE/GE30S.sql <==
/****************************************************************************/
/* GE30 ( ﾊﾟﾗﾒｰﾀﾃｰﾌﾞﾙ )                                                     */
/*                                                                          */
/* Created : 2014/07/02 16:17:56                                            */
/****************************************************************************/
CREATE TABLE GE30 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID           */
 , PTN_ID       VARCHAR (   20 )                    NOT NULL            /*  20 定型文ID         */
 , FROM_ID      VARCHAR (   50 )                    NOT NULL            /*  30 送信者ID         */
 , TO_ID        VARCHAR ( 4000 )                                        /*  40 宛先(TO)         */
 , CC_ID        VARCHAR ( 4000 )                                        /*  50 宛先(CC)         */
 , BCC_ID       VARCHAR ( 4000 )                                        /*  60 宛先(BCC)        */
 , H_TXT        VARCHAR ( 1000 )                                        /*  70 ﾍｯﾀﾞｰ自由文      */
 , F_TXT        VARCHAR ( 1000 )                                        /*  80 ﾌｯﾀｰ自由文       */
 , GAMEN_URL    VARCHAR (  300 )                                        /*  90 画面URL(暗号化)  */
 , PARAM0       VARCHAR ( 4000 )                                        /* 100 ﾊﾟﾗﾒｰﾀ0          */
 , PARAM1       VARCHAR ( 4000 )                                        /* 110 ﾊﾟﾗﾒｰﾀ1          */
 , PARAM2       VARCHAR ( 1000 )                                        /* 120 ﾊﾟﾗﾒｰﾀ2          */
 , PARAM3       VARCHAR ( 1000 )                                        /* 130 ﾊﾟﾗﾒｰﾀ3          */
 , PARAM4       VARCHAR ( 1000 )                                        /* 140 ﾊﾟﾗﾒｰﾀ4          */
 , PARAM5       VARCHAR ( 1000 )                                        /* 150 ﾊﾟﾗﾒｰﾀ5          */
 , PARAM6       VARCHAR ( 1000 )                                        /* 160 ﾊﾟﾗﾒｰﾀ6          */
 , PARAM7       VARCHAR ( 1000 )                                        /* 170 ﾊﾟﾗﾒｰﾀ7          */
 , PARAM8       VARCHAR ( 1000 )                                        /* 180 ﾊﾟﾗﾒｰﾀ8          */
 , PARAM9       VARCHAR ( 1000 )                                        /* 190 ﾊﾟﾗﾒｰﾀ9          */
 , ATTACH1      VARCHAR (  256 )                                        /* 200 添付1            */
 , ATTACH2      VARCHAR (  256 )                                        /* 210 添付2            */
 , ATTACH3      VARCHAR (  256 )                                        /* 220 添付3            */
 , ATTACH4      VARCHAR (  256 )                                        /* 230 添付4            */
 , ATTACH5      VARCHAR (  256 )                                        /* 240 添付5            */
 , SNDTIME      VARCHAR (   14 )                                        /* 250 送信日次         */
 , UNIQ         SERIAL                                                  /* 800 ﾕﾆｰｸｷｰ           */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET        VARCHAR (   14 )                                        /* 820 登録日時         */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG           */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG         */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成社員         */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時         */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG           */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG         */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者           */
);
